@@ -871,16 +871,15 @@ class KiwiEntry(PropertyObject, gtk.Entry):
         if not self._mask:
             return
 
-        if (direction == gtk.DIR_TAB_FORWARD or
-            direction == gtk.DIR_DOWN):
-            inc = 1
-        if (direction == gtk.DIR_TAB_BACKWARD or
-            direction == gtk.DIR_UP):
-            inc = -1
-
         field = self._current_field
 
-        field += inc
+        if (direction == gtk.DIR_TAB_FORWARD or
+            direction == gtk.DIR_DOWN):
+            field += 1
+        elif (direction == gtk.DIR_TAB_BACKWARD or
+              direction == gtk.DIR_UP):
+            field = -1
+
         # Leaving the entry
         if field == len(self._mask_fields) or field == -1:
             self.select_region(0, 0)
@@ -933,7 +932,8 @@ class KiwiEntry(PropertyObject, gtk.Entry):
         if field is None:
             self.set_position(self._pos)
         else:
-            self._current_field = field
+            if self._current_field != -1:
+                self._current_field = field
             self._pos = pos
 
     def _on_changed(self, widget):
